==> jc-1.4.0.tar.gz: javax/net/ssl/SSLContextSpi.h <==
// public abstract class javax.net.ssl.SSLContextSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 860bb69acbf20f89 javax_net_ssl_SSLContextSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_SSLContextSpi_H_
#define _JC_javax_net_ssl_SSLContextSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_javax_net_ssl_SSLServerSocketFactory$object;
struct _jc_javax_net_ssl_SSLSessionContext$object;
struct _jc_javax_net_ssl_SSLSocketFactory$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLContextSpi$sub_refs	_jc_javax_net_ssl_SSLContextSpi$sub_refs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs	_jc_javax_net_ssl_SSLContextSpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$refs	_jc_javax_net_ssl_SSLContextSpi$refs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$nonrefs	_jc_javax_net_ssl_SSLContextSpi$nonrefs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$object	_jc_javax_net_ssl_SSLContextSpi$object;

typedef const struct _jc_javax_net_ssl_SSLContextSpi$vmethods	_jc_javax_net_ssl_SSLContextSpi$vmethods;
typedef const struct _jc_javax_net_ssl_SSLContextSpi$vtable	_jc_javax_net_ssl_SSLContextSpi$vtable;
typedef const struct _jc_javax_net_ssl_SSLContextSpi$vtype	_jc_javax_net_ssl_SSLContextSpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLContextSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetClientSessionContext$b2000fb2b4100822(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
extern struct _jc_object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetServerSessionContext$29cc600184bce31b(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
extern struct _jc_javax_net_ssl_SSLServerSocketFactory$object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetServerSocketFactory$ea765cae88ebe591(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
extern struct _jc_javax_net_ssl_SSLSocketFactory$object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetSocketFactory$815833768b868fad(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
extern void _jc_javax_net_ssl_SSLContextSpi$method$engineInit$689c9e8c18a70c8f(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_security_SecureRandom$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetClientSessionContext$b2000fb2b4100822;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetServerSessionContext$29cc600184bce31b;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetServerSocketFactory$ea765cae88ebe591;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetSocketFactory$815833768b868fad;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineInit$689c9e8c18a70c8f;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLContextSpi$vmethods {
	struct _jc_object	*(*engineGetClientSessionContext$b2000fb2b4100822)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
	struct _jc_object	*(*engineGetServerSessionContext$29cc600184bce31b)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
	struct _jc_javax_net_ssl_SSLServerSocketFactory$object	*(*engineGetServerSocketFactory$ea765cae88ebe591)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
	struct _jc_javax_net_ssl_SSLSocketFactory$object	*(*engineGetSocketFactory$815833768b868fad)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *);
	void	(*engineInit$689c9e8c18a70c8f)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_security_SecureRandom$object *);
};

// Vtable
struct _jc_javax_net_ssl_SSLContextSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_SSLContextSpi$vmethods	javax_net_ssl_SSLContextSpi;
};

// Vtype
struct _jc_javax_net_ssl_SSLContextSpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLContextSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLContextSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLContextSpi$refs {
    _jc_javax_net_ssl_SSLContextSpi$sub_refs	javax_net_ssl_SSLContextSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLContextSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs	javax_net_ssl_SSLContextSpi;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLContextSpi$object {
	_jc_javax_net_ssl_SSLContextSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLContextSpi$vtype	*vtype;
	_jc_javax_net_ssl_SSLContextSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLContextSpi$vtype _jc_javax_net_ssl_SSLContextSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLContextSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLContextSpi$class_object;

#endif	/* _JC_javax_net_ssl_SSLContextSpi_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLContextSpi.h <==
// public abstract class javax.net.ssl.SSLContextSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 860bb69acbf20f89 javax_net_ssl_SSLContextSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_SSLContextSpi_H_
#define _JC_javax_net_ssl_SSLContextSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_javax_net_ssl_SSLServerSocketFactory$object;
struct _jc_javax_net_ssl_SSLSessionContext$object;
struct _jc_javax_net_ssl_SSLSocketFactory$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLContextSpi$sub_refs	_jc_javax_net_ssl_SSLContextSpi$sub_refs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs	_jc_javax_net_ssl_SSLContextSpi$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$refs	_jc_javax_net_ssl_SSLContextSpi$refs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$nonrefs	_jc_javax_net_ssl_SSLContextSpi$nonrefs;
typedef struct _jc_javax_net_ssl_SSLContextSpi$object	_jc_javax_net_ssl_SSLContextSpi$object;

typedef const struct _jc_javax_net_ssl_SSLContextSpi$vmethods	_jc_javax_net_ssl_SSLContextSpi$vmethods;
typedef const struct _jc_javax_net_ssl_SSLContextSpi$vtable	_jc_javax_net_ssl_SSLContextSpi$vtable;
typedef const struct _jc_javax_net_ssl_SSLContextSpi$vtype	_jc_javax_net_ssl_SSLContextSpi$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLContextSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetClientSessionContext$b2000fb2b4100822(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetServerSessionContext$29cc600184bce31b(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_SSLServerSocketFactory$object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetServerSocketFactory$ea765cae88ebe591(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_SSLSocketFactory$object *_jc_javax_net_ssl_SSLContextSpi$method$engineGetSocketFactory$815833768b868fad(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_SSLContextSpi$method$engineInit$689c9e8c18a70c8f(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetClientSessionContext$b2000fb2b4100822;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetServerSessionContext$29cc600184bce31b;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetServerSocketFactory$ea765cae88ebe591;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineGetSocketFactory$815833768b868fad;
extern _jc_method _jc_javax_net_ssl_SSLContextSpi$method_info$engineInit$689c9e8c18a70c8f;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLContextSpi$vmethods {
	struct _jc_object	*(*engineGetClientSessionContext$b2000fb2b4100822)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetServerSessionContext$29cc600184bce31b)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
	struct _jc_javax_net_ssl_SSLServerSocketFactory$object	*(*engineGetServerSocketFactory$ea765cae88ebe591)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
	struct _jc_javax_net_ssl_SSLSocketFactory$object	*(*engineGetSocketFactory$815833768b868fad)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *) _JC_JCNI_ATTR;
	void	(*engineInit$689c9e8c18a70c8f)(_jc_env *, struct _jc_javax_net_ssl_SSLContextSpi$object *, struct _jc_object_array *, struct _jc_object_array *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_SSLContextSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_SSLContextSpi$vmethods	javax_net_ssl_SSLContextSpi;
};

// Vtype
struct _jc_javax_net_ssl_SSLContextSpi$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLContextSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLContextSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLContextSpi$refs {
    _jc_javax_net_ssl_SSLContextSpi$sub_refs	javax_net_ssl_SSLContextSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLContextSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_SSLContextSpi$sub_nonrefs	javax_net_ssl_SSLContextSpi;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLContextSpi$object {
	_jc_javax_net_ssl_SSLContextSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLContextSpi$vtype	*vtype;
	_jc_javax_net_ssl_SSLContextSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLContextSpi$vtype _jc_javax_net_ssl_SSLContextSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLContextSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLContextSpi$class_object;

#endif	/* _JC_javax_net_ssl_SSLContextSpi_H_ */
